## ![](../../../../Images32x32Metro/OBJECT_FUNCTION.png "") Function:\[AdventureWorks2016CTP3\].\[sys\].\[fn_helpdatatypemap\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Functions](../../../../DbEngine/(local)/AdventureWorks2016CTP3/functions.md) > **sys.fn_helpdatatypemap**

---
### Function properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | Table |
| Is schema bound |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| Is deterministic |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| Implementation type | Transact SQL |
| ID | -705212384 |

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|DataType |Max length |ReadOnly|
|-|-|-|-|-|
|@source_dbms| |sysname|128|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@source_version| |sysname|128|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@source_type| |sysname|128|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@destination_dbms| |sysname|128|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@destination_version| |sysname|128|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@destination_type| |sysname|128|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@defaults_only| |bit|1|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordset returned
|Name |Datatype |Max length |
|-|-|-|
|mapping_id|int|4|
|source_dbms|nvarchar|128|
|source_version|nvarchar|128|
|source_type|nvarchar|128|
|source_length_min|bigint|8|
|source_length_max|bigint|8|
|source_precision_min|bigint|8|
|source_precision_max|bigint|8|
|source_scale_min|int|4|
|source_scale_max|int|4|
|source_nullable|bit|1|
|source_createparams|int|4|
|destination_dbms|nvarchar|128|
|destination_version|nvarchar|128|
|destination_type|nvarchar|128|
|destination_length|bigint|8|
|destination_precision|bigint|8|
|destination_scale|int|4|
|destination_nullable|bit|1|
|destination_createparams|int|4|
|dataloss|bit|1|
|is_default|bit|1|

---
###  Permissions
No permissions defined

---
### Objects that depend on \[sys\].\[fn_helpdatatypemap\]
 No dependencies exist

---
### Objects that \[sys\].\[fn_helpdatatypemap\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO

--
-- Name:
--        fn_helpdatatypemap
--
-- Description:
--        Retrieve data type map as inline table
--
-- Returns:
--        0 if successful
--        1 if failed
--
-- Security:
--        public
--
-- Notes:
--        Produces the full data type map based on input
--        parameters.  Includes filtered version based
--        on source and destination dbms, and defaults.
--

CREATE FUNCTION sys.fn_helpdatatypemap
(
    @source_dbms            sysname    = '%',
    @source_version            sysname    = '%',
    @source_type            sysname    = '%',
    @destination_dbms        sysname    = '%',
    @destination_version    sysname    = '%',
    @destination_type        sysname    = '%',
    @defaults_only            bit        = 0
)
RETURNS @retDataMap TABLE
(
    mapping_id                    int,
    source_dbms                    sysname collate database_default,
    source_version                sysname NULL,
    source_type                    sysname collate database_default,
    source_length_min            bigint,
    source_length_max            bigint,
    source_precision_min        bigint,
    source_precision_max        bigint,
    source_scale_min            int,
    source_scale_max            int,
    source_nullable                bit,
    source_createparams            int,
    destination_dbms            sysname collate database_default,
    destination_version            sysname collate database_default NULL,
    destination_type            sysname collate database_default,
    destination_length            bigint,
    destination_precision        bigint,
    destination_scale            int,
    destination_nullable        bit,
    destination_createparams    int,
    dataloss                    bit,
    is_default                    bit
)
AS
BEGIN
    DECLARE @filter  nvarchar(4000)

    -- Prepare dbms for case insensitive searches
    SET @source_dbms        = UPPER(@source_dbms)
    SET @destination_dbms    = UPPER(@destination_dbms)

    INSERT    @retDataMap
    SELECT    dm.datatype_mapping_id,
            src.dbms,
            src.version,
            srcdt.type,
            map.src_len_min,
            map.src_len_max,
            map.src_prec_min,
            map.src_prec_max,
            map.src_scale_min,
            map.src_scale_max,
            map.src_nullable,
            srcdt.createparams,
            dest.dbms,
            dest.version,
            destdt.type,
            dm.dest_length,
            CASE
                WHEN dm.dest_precision &gt; 0 and dm.dest_scale &gt; dm.dest_precision THEN dm.dest_scale
                ELSE dm.dest_precision
            END,
            dm.dest_scale,
            dm.dest_nullable,
            dm.dest_createparams,
            dm.dataloss,
            case
                when map.default_datatype_mapping_id = dm.datatype_mapping_id then 1
                else 0
            end as [is_default]
    FROM    msdb.dbo.MSdbms src,
            msdb.dbo.MSdbms dest,
            msdb.dbo.MSdbms_datatype srcdt,
            msdb.dbo.MSdbms_datatype destdt,
            msdb.dbo.MSdbms_map map,
            msdb.dbo.MSdbms_datatype_mapping dm
    WHERE    src.dbms_id                = map.src_dbms_id
      AND    dest.dbms_id            = map.dest_dbms_id
      AND    srcdt.datatype_id        = map.src_datatype_id
      AND    map.map_id                = dm.map_id
      AND    dm.dest_datatype_id        = destdt.datatype_id
      AND   (@source_dbms = '%' OR src.dbms = @source_dbms)
      AND   sys.fn_IHcompareversion(src.version, @source_version) = 1
      AND   (@destination_dbms = '%' OR dest.dbms = @destination_dbms)
      AND   sys.fn_IHcompareversion(dest.version, @destination_version) = 1
      AND   (@source_type = N'%' OR srcdt.type = @source_type)
      AND   (@destination_type = N'%' OR destdt.type = @destination_type)
      AND   (@defaults_only = 0 OR map.default_datatype_mapping_id = dm.datatype_mapping_id)
    ORDER BY src.dbms,
             src.version,
             dest.dbms,
             dest.version,
             srcdt.type,
             [is_default] desc,
             destdt.type
    
    RETURN
END
GO
  
~~~

---
### See also
[List of functions](../functions.md)

