## ![](../../../../Images32x32Metro/OBJECT_FUNCTION.png "") Function:\[AdventureWorks2016CTP3\].\[dbo\].\[ufnGetProductDealerPrice\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Functions](../../../../DbEngine/(local)/AdventureWorks2016CTP3/functions.md) > **ufnGetProductDealerPrice**

---
###  Description  
 Scalar function returning the dealer price for a given product on a particular order date. 



---
### Function properties
| Name | Value |
|-|-|
| Schema | [\[dbo\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/1.md) |
| Owner | [\[dbo\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Users/1.md) |
| Creation date | 11/16/2015 |
| Type | Scalar |
| Is schema bound |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| Is deterministic |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| Implementation type | Transact SQL |
| ID | 1389248004 |

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|DataType |Max length |ReadOnly|
|-|-|-|-|-|
|@ProductID|Input parameter for the scalar function ufnGetProductDealerPrice. Enter a valid ProductID from the Production.Product table.|int|4|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@OrderDate|Input parameter for the scalar function ufnGetProductDealerPrice. Enter a valid order date.|datetime|8|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordset returned
|Name |Datatype |Max length |
|-|-|-|
|@Return|money|8|

---
###  Permissions
No permissions defined

---
### Objects that depend on \[dbo\].\[ufnGetProductDealerPrice\]
 No dependencies exist

---
### Objects that \[dbo\].\[ufnGetProductDealerPrice\] depends on
|Object name|Object type|Dep level|
|-|-|-|
|[\[Production\].\[Product\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/146099561.md)|Table|1|
|[\[Production\].\[ProductListPriceHistory\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/674101442.md)|Table|1|

 Total 2 object(s)

---
### Column level dependencies
|Object name|Column|Object type|
|-|-|-|
|[\[Production\].\[Product\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/146099561.md)|ProductID|Table|
|[\[Production\].\[ProductListPriceHistory\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/674101442.md)|ProductID|Table|
|[\[Production\].\[ProductListPriceHistory\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/674101442.md)|StartDate|Table|
|[\[Production\].\[ProductListPriceHistory\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/674101442.md)|EndDate|Table|
|[\[Production\].\[ProductListPriceHistory\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/674101442.md)|ListPrice|Table|

 Total 5 column(s)

---
### Graphical dependencies
Click [here](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Functions/1389248004_gr.md) to view dependencies graphically

---
###  Extended properties  
|Name |Value |
|-|-|
|MS_Description|Scalar function returning the dealer price for a given product on a particular order date.|

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO



CREATE FUNCTION [dbo].[ufnGetProductDealerPrice](@ProductID [int], @OrderDate [datetime])
RETURNS [money] 
AS 
-- Returns the dealer price for the product on a specific date.
BEGIN
    DECLARE @DealerPrice money;
    DECLARE @DealerDiscount money;

    SET @DealerDiscount = 0.60  -- 60% of list price

    SELECT @DealerPrice = plph.[ListPrice] * @DealerDiscount 
    FROM [Production].[Product] p 
        INNER JOIN [Production].[ProductListPriceHistory] plph 
        ON p.[ProductID] = plph.[ProductID] 
            AND p.[ProductID] = @ProductID 
            AND @OrderDate BETWEEN plph.[StartDate] AND COALESCE(plph.[EndDate], CONVERT(datetime, '99991231', 112)); -- Make sure we get all the prices!

    RETURN @DealerPrice;
END;
GO
EXEC sp_addextendedproperty N'MS_Description', N'Scalar function returning the dealer price for a given product on a particular order date.', 'SCHEMA', N'dbo', 'FUNCTION', N'ufnGetProductDealerPrice', NULL, NULL
GO
EXEC sp_addextendedproperty N'MS_Description', N'Input parameter for the scalar function ufnGetProductDealerPrice. Enter a valid ProductID from the Production.Product table.', 'SCHEMA', N'dbo', 'FUNCTION', N'ufnGetProductDealerPrice', 'PARAMETER', N'@ProductID'
GO
EXEC sp_addextendedproperty N'MS_Description', N'Input parameter for the scalar function ufnGetProductDealerPrice. Enter a valid order date.', 'SCHEMA', N'dbo', 'FUNCTION', N'ufnGetProductDealerPrice', 'PARAMETER', N'@OrderDate'
GO
  
~~~

---
### See also
[List of functions](../functions.md)

