## ![](../../../../Images32x32Metro/OBJECT_FUNCTION.png "") Function:\[AdventureWorks2016CTP3\].\[dbo\].\[ufnGetProductStandardCost\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Functions](../../../../DbEngine/(local)/AdventureWorks2016CTP3/functions.md) > **ufnGetProductStandardCost**

---
###  Description  
 Scalar function returning the standard cost for a given product on a particular order date. 



---
### Function properties
| Name | Value |
|-|-|
| Schema | [\[dbo\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/1.md) |
| Owner | [\[dbo\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Users/1.md) |
| Creation date | 11/16/2015 |
| Type | Scalar |
| Is schema bound |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| Is deterministic |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| Implementation type | Transact SQL |
| ID | 1421248118 |

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|DataType |Max length |ReadOnly|
|-|-|-|-|-|
|@ProductID|Input parameter for the scalar function ufnGetProductStandardCost. Enter a valid ProductID from the Production.Product table.|int|4|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@OrderDate|Input parameter for the scalar function ufnGetProductStandardCost. Enter a valid order date.|datetime|8|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordset returned
|Name |Datatype |Max length |
|-|-|-|
|@Return|money|8|

---
###  Permissions
No permissions defined

---
### Objects that depend on \[dbo\].\[ufnGetProductStandardCost\]
 No dependencies exist

---
### Objects that \[dbo\].\[ufnGetProductStandardCost\] depends on
|Object name|Object type|Dep level|
|-|-|-|
|[\[Production\].\[Product\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/146099561.md)|Table|1|
|[\[Production\].\[ProductCostHistory\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/434100587.md)|Table|1|

 Total 2 object(s)

---
### Column level dependencies
|Object name|Column|Object type|
|-|-|-|
|[\[Production\].\[Product\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/146099561.md)|ProductID|Table|
|[\[Production\].\[ProductCostHistory\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/434100587.md)|ProductID|Table|
|[\[Production\].\[ProductCostHistory\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/434100587.md)|StartDate|Table|
|[\[Production\].\[ProductCostHistory\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/434100587.md)|EndDate|Table|
|[\[Production\].\[ProductCostHistory\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/434100587.md)|StandardCost|Table|

 Total 5 column(s)

---
### Graphical dependencies
Click [here](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Functions/1421248118_gr.md) to view dependencies graphically

---
###  Extended properties  
|Name |Value |
|-|-|
|MS_Description|Scalar function returning the standard cost for a given product on a particular order date.|

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO

CREATE FUNCTION [dbo].[ufnGetProductStandardCost](@ProductID [int], @OrderDate [datetime])
RETURNS [money] 
AS 
-- Returns the standard cost for the product on a specific date.
BEGIN
    DECLARE @StandardCost money;

    SELECT @StandardCost = pch.[StandardCost] 
    FROM [Production].[Product] p 
        INNER JOIN [Production].[ProductCostHistory] pch 
        ON p.[ProductID] = pch.[ProductID] 
            AND p.[ProductID] = @ProductID 
            AND @OrderDate BETWEEN pch.[StartDate] AND COALESCE(pch.[EndDate], CONVERT(datetime, '99991231', 112)); -- Make sure we get all the prices!

    RETURN @StandardCost;
END;
GO
EXEC sp_addextendedproperty N'MS_Description', N'Scalar function returning the standard cost for a given product on a particular order date.', 'SCHEMA', N'dbo', 'FUNCTION', N'ufnGetProductStandardCost', NULL, NULL
GO
EXEC sp_addextendedproperty N'MS_Description', N'Input parameter for the scalar function ufnGetProductStandardCost. Enter a valid ProductID from the Production.Product table.', 'SCHEMA', N'dbo', 'FUNCTION', N'ufnGetProductStandardCost', 'PARAMETER', N'@ProductID'
GO
EXEC sp_addextendedproperty N'MS_Description', N'Input parameter for the scalar function ufnGetProductStandardCost. Enter a valid order date.', 'SCHEMA', N'dbo', 'FUNCTION', N'ufnGetProductStandardCost', 'PARAMETER', N'@OrderDate'
GO
  
~~~

---
### See also
[List of functions](../functions.md)

