## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_redirect_publisher\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_redirect_publisher**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -1065960762 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@original_publisher| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@publisher_db| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@redirected_publisher| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_redirect_publisher\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_redirect_publisher\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO
--
-- Name: sp_redirect_publisher
--
-- Descriptions: Redirect the publisher of a published database to a 
--               new target publisher. Target can be an explicit node
--               or a HADRon virtual network name.
--
--               If the target of the redirection is NULL, the current
--               entry for the publisher database pair, if it exists,
--               is removed.
--
-- Parameters: as defined in create statement
--
-- Returns: 0 - success, 1 - failure
--          raise error on failure
--
-- Security: Public procedure invoked via RPC. db_owner check
--
create procedure sys.sp_redirect_publisher
(
    @original_publisher sysname,
    @publisher_db sysname,
    @redirected_publisher sysname = null
)
as
begin
    set nocount on
   
    declare @dbname sysname = db_name()
 
    -- Security check
    --
    if is_member(N'db_owner') &lt;&gt; 1
    begin
        raiserror (21873, 16, -1, 'sys.sp_redirect_publisher')
        return 1
    end
    
    -- Has to be executed from a distribution database
    --
    if (sys.fn_MSrepl_isdistdb (@dbname) &lt;&gt; 1)
    begin
        raiserror(21874, 16, -1, 'sys.sp_redirect_publisher', @dbname)
        return 1
    end
 
    -- Input parameters must both be non-null
    --
    if @original_publisher is null or
        @publisher_db is null
    begin
        raiserror (21875, 16, -1, 'sys.sp_redirect_publisher')
        return 1
    end
    
    if exists 
        (    select redirected_publisher from MSredirected_publishers
            where publisher_db = rtrim(@publisher_db)
            and   upper(original_publisher) = upper(rtrim(@original_publisher)))
    begin
        if @redirected_publisher is not null
        begin
            update MSredirected_publishers 
            set redirected_publisher = rtrim(@redirected_publisher)
            where publisher_db = rtrim(@publisher_db)
            and   upper(original_publisher) = upper(rtrim(@original_publisher))
        end
        else
        begin
            delete from MSredirected_publishers 
            where publisher_db = rtrim(@publisher_db)
            and   upper(original_publisher) = upper(rtrim(@original_publisher))            
        end
    end
    else    
    begin
        insert into MSredirected_publishers
        values (rtrim(@original_publisher), rtrim(@publisher_db), rtrim(@redirected_publisher))
    end     
        
    return 0                          
end
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

