## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_schemafilter\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_schemafilter**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -264277491 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@publisher| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@schema| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@operation| |nvarchar|4|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_schemafilter\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_schemafilter\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO

--
-- Name:
--        sp_schemafilter
--
-- Description:
--        Update the schema filter set used to control those schema
--        whose tables are examined by sp_ORAenumpublishertables (Oracle specific)
--
-- Inputs:
--        @publisher        == name of Oracle publisher
--        @operation        == operation ('add', 'drop', 'help')
--        @schema            == schema name 
--
-- Returns:
--        Return code (0 for success, 1 for failure)
--
-- Security:
--        public -- call must be sysadmin
--
-- Notes:
--        This stored procedure is provided so that the administrator of Oracle
--        publishing can control those schema that are not included when
--        displaying the tables eligible for publishing within the add publication
--        wizard.  A default filter set is created when the HREPL package is downloaded 
--        to the publisher.  This stored procedure allows the entries in the filter set
--        to be both viewed and updated.
--
--        Operation    Action
--
--        'add'    -    Adds the schema specified in @schema to the filter set
--                if not already present. 
--        'drop    -    Drop the schema specified in @schema from the filter set
--                if present.
--        'help'    -    Returns a result set identifying the schema currently 
--                in the filter set.  If @schema is specified, the result set
--                will be empty if the schema is not in the result set, or
--                will contain the single schema if it was present in the
--                result set. (default)        
--

CREATE PROCEDURE sys.sp_schemafilter
(
    @publisher        sysname,
    @schema            sysname = NULL,
    @operation        nvarchar(4) = N'help'
)
AS
BEGIN
    DECLARE @cmd            nvarchar(4000)
    DECLARE @retcode        int
    DECLARE @publisher_type    sysname

    -- Security Check: requires sysadmin, done in sp_MSrepl_getpublisherinfo

    SET @retcode = 0

    EXEC @retcode = sys.sp_MSrepl_getpublisherinfo    @publisher        = @publisher,
                                                    @rpcheader        = @cmd OUTPUT,
                                                    @publisher_type    = @publisher_type OUTPUT,
                                                    @hreplOnly        = 1                            
    
    IF @retcode &lt;&gt; 0
        RETURN (@retcode)

    -- Error if the publisher is not an Oracle publisher
    IF @publisher_type NOT LIKE 'ORACLE%'
    BEGIN
        RAISERROR (21687, 16, -1, @publisher, @publisher_type)
            RETURN (1)
    END

    SET @publisher = UPPER(@publisher) COLLATE DATABASE_DEFAULT
    set @cmd = @cmd + N'sys.sp_ORASchemaFilter'
    
    EXEC @retcode = @cmd    @publisher,
                @schema,
                @operation
    RETURN (@retcode)
END
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

