## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_MSrecordsnapshotdeliveryprogress\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_MSrecordsnapshotdeliveryprogress**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -283403333 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@snapshot_session_token| |nvarchar|260|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@snapshot_progress_token| |nvarchar|500|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_MSrecordsnapshotdeliveryprogress\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_MSrecordsnapshotdeliveryprogress\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO
--
-- Name: sp_MSrecordsnapshotdeliveryprogress
--
-- Description: This procedure is used by the distribution agent or the merge
--              agent to record a snapshot delivery work item that has been
--              applied to a subscriber database in the 
--              MSsnapshotdeliveryprogress table. In the event of restarting 
--              an interrupted snapshot delivery process, the distribution or
--              merge agent can use the information stored in the 
--              MSsnapshotdeliveryprogress table to avoid redoing snapshot
--              delivery processing that has already been applied to the 
--              subscriber.
-- 
-- Note: This procedure should only be called by the distribution agent or
--       the merge agent at the subscriber database.
--
-- Parameters: @snapshot_session_token nvarchar(260) (mandatory)
--               - a UniCode string that uniquely identifies a snapshot
--                 delivery session. For now, this will be a the full folder
--                 path of the particular snapshot being applied (hence the
--                 260 characters size).
--             @snapshot_progress_token nvarchar(500) (mandatory)
--               - A unicode string that uniquely identifies a snapshot work
--                 item (schema creation, bulk-loading data) that has been 
--                 applied to the subscriber. 
--
-- Returns: 0 - succeeded
--          1 - failed
-- 
-- Security: Execute permission of this procedure is granted to public;
--           procedural security check will be performed to make sure
--           that the caller is either a db_owner of the current database
--           or a sysadmin. 
--
create procedure sys.sp_MSrecordsnapshotdeliveryprogress (
    @snapshot_session_token nvarchar(260),
    @snapshot_progress_token nvarchar(500)
    )
as
begin
    set nocount on
    set arithabort on
    declare @retcode int
    declare @snapshot_progress_token_hash int
    select @retcode = 0

    exec @retcode = sys.sp_MSreplcheck_subscribe 
    if @retcode &lt;&gt; 0 or @@error &lt;&gt; 0
    begin
        select @retcode = 1
        goto FAILURE
    end
    
    if object_id('dbo.MSsnapshotdeliveryprogress') is null
    begin
        create table dbo.MSsnapshotdeliveryprogress 
        (
           session_token nvarchar(260) not null,
           progress_token_hash int not null,
           progress_token nvarchar(500) not null,
           progress_timestamp datetime default getdate()
        )
        if @@ERROR &lt;&gt; 0
        begin 
            select @retcode = 1
            goto FAILURE
        end        
        create index ci_MSsnapshotdeliveryprogress_progress_token_hash 
            on dbo.MSsnapshotdeliveryprogress(progress_token_hash)
        if @@ERROR &lt;&gt; 0
        begin 
            select @retcode = 1
            goto FAILURE
        end        
        create index nci_MSsnapshotdeliveryprogress_session_token
            on dbo.MSsnapshotdeliveryprogress(session_token)
        if @@ERROR &lt;&gt; 0
        begin 
            select @retcode = 1
            goto FAILURE
        end        
        exec @retcode = dbo.sp_MS_marksystemobject 'dbo.MSsnapshotdeliveryprogress'
        if @retcode &lt;&gt; 0 or @@ERROR &lt;&gt; 0
        begin 
            select @retcode = 1
            goto FAILURE
        end        
    end 

    select @snapshot_progress_token_hash = sys.fn_repl32bitstringhash(@snapshot_progress_token)
    if @retcode &lt;&gt; 0 or @@ERROR &lt;&gt; 0
    begin 
        select @retcode = 1
        goto FAILURE
    end        

    if exists (select * from MSsnapshotdeliveryprogress 
                where progress_token_hash = @snapshot_progress_token_hash
                  and progress_token = @snapshot_progress_token
                  and session_token = @snapshot_session_token)
    begin
        update MSsnapshotdeliveryprogress
           set progress_timestamp = getdate()
         where progress_token = @snapshot_progress_token
           and session_token = @snapshot_session_token
        if @@ERROR &lt;&gt; 0
        begin 
            select @retcode = 1
            goto FAILURE
        end        
    end
    else
    begin
        insert MSsnapshotdeliveryprogress 
            values (
                @snapshot_session_token,
                @snapshot_progress_token_hash,
                @snapshot_progress_token, 
                default)
        if @@ERROR &lt;&gt; 0
        begin 
            select @retcode = 1
            goto FAILURE
        end                 
    end         
    if @@ERROR &lt;&gt; 0
    begin 
        select @retcode = 1
        goto FAILURE
    end        

FAILURE:
    return @retcode
end
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

