## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_monitor\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_monitor**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -305049472 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
 No parameters exist

---
### Recordsets returned
|Name |Datatype |Max length |
|-|-|-|
|last_run|datetime|8|
|current_run|datetime|8|
|seconds|int|4|

|Name |Datatype |Max length |
|-|-|-|
|cpu_busy|varchar|25|
|io_busy|varchar|25|
|idle|varchar|25|

|Name |Datatype |Max length |
|-|-|-|
|packets_received|varchar|24|
|packets_sent|varchar|24|
|packet_errors|varchar|24|

|Name |Datatype |Max length |
|-|-|-|
|total_read|varchar|19|
|total_write|varchar|19|
|total_errors|varchar|19|
|connections|varchar|18|

---
### Objects that depend on \[sys\].\[sp_monitor\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_monitor\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO
create procedure sys.sp_monitor
as
if (not (is_srvrolemember('sysadmin') = 1))  -- Make sure that it is the SA executing this.
        begin
                raiserror(15247,-1,-1)
                return(1)
        end

/*
**  Declare variables to be used to hold current monitor values.
*/
declare @now         datetime
declare @cpu_busy     int
declare @io_busy    int
declare @idle        int
declare @pack_received    int
declare @pack_sent    int
declare @pack_errors    int
declare @connections    int
declare @total_read    int
declare @total_write    int
declare @total_errors    int

declare @oldcpu_busy     int    /* used to see if DataServer has been rebooted */
declare @interval    int
declare @mspertick    int    /* milliseconds per tick */

/*
**  If we're in a transaction, disallow this since it might make recovery
**  impossible.
*/
set implicit_transactions off
if @@trancount &gt; 0
    begin
        raiserror(15002,-1,-1,'sp_monitor')
        return (1)
    end

/*
**  Set @mspertick.  This is just used to make the numbers easier to handle
**  and avoid overflow.
*/
select @mspertick = convert(int, @@timeticks / 1000.0)

/*
**  Get current monitor values.
*/
select
    @now = getdate(),
    @cpu_busy = @@cpu_busy,
    @io_busy = @@io_busy,
    @idle = @@idle,
    @pack_received = @@pack_received,
    @pack_sent = @@pack_sent,
    @connections = @@connections,
    @pack_errors = @@packet_errors,
    @total_read = @@total_read,
    @total_write = @@total_write,
    @total_errors = @@total_errors

/*
**  Check to see if DataServer has been rebooted.  If it has then the
**  value of @@cpu_busy will be less than the value of spt_monitor.cpu_busy.
**  If it has update spt_monitor.
*/
select @oldcpu_busy = cpu_busy
    from master.dbo.spt_monitor
if @oldcpu_busy &gt; @cpu_busy
begin
    update master.dbo.spt_monitor
        set
            lastrun = @now,
            cpu_busy = @cpu_busy,
            io_busy = @io_busy,
            idle = @idle,
            pack_received = @pack_received,
            pack_sent = @pack_sent,
            connections = @connections,
            pack_errors = @pack_errors,
            total_read = @total_read,
            total_write = @total_write,
            total_errors = @total_errors
end

/*
**  Now print out old and new monitor values.
*/
set nocount on
select @interval = datediff(ss, lastrun, @now)
    from master.dbo.spt_monitor
/* To prevent a divide by zero error when run for the first
** time after boot up
*/
if @interval = 0
    select @interval = 1
select last_run = lastrun, current_run = @now, seconds = @interval
    from master.dbo.spt_monitor

select
    cpu_busy = substring(convert(varchar(11),
        convert(int, ((@cpu_busy * @mspertick) / 1000)))
        + '('
        + convert(varchar(11), convert(int, (((@cpu_busy - cpu_busy)
        * @mspertick) / 1000)))
        + ')'
        + '-'
        + convert(varchar(11), convert(int, ((((@cpu_busy - cpu_busy)
        * @mspertick) / 1000) * 100) / @interval))
        + '%',
        1, 25),
    io_busy = substring(convert(varchar(11),
        convert(int, ((@io_busy * @mspertick) / 1000)))
        + '('
        + convert(varchar(11), convert(int, (((@io_busy - io_busy)
        * @mspertick) / 1000)))
        + ')'
        + '-'
        + convert(varchar(11), convert(int, ((((@io_busy - io_busy)
        * @mspertick) / 1000) * 100) / @interval))
        + '%',
        1, 25),
    idle = substring(convert(varchar(11),
        convert(int, ((convert(bigint,@idle) * @mspertick) / 1000)))
        + '('
        + convert(varchar(11), convert(int, (((@idle - idle)
        * @mspertick) / 1000)))
        + ')'
        + '-'
        + convert(varchar(11), convert(int, ((((@idle - idle)
        * @mspertick) / 1000) * 100) / @interval))
        + '%',
        1, 25)
from master.dbo.spt_monitor

select
    packets_received = substring(convert(varchar(11), @pack_received) + '(' +
        convert(varchar(11), @pack_received - pack_received) + ')', 1, 25),
    packets_sent = substring(convert(varchar(11), @pack_sent) + '(' +
        convert(varchar(11), @pack_sent - pack_sent) + ')', 1, 25),
    packet_errors = substring(convert(varchar(11), @pack_errors) + '(' +
        convert(varchar(11), @pack_errors - pack_errors) + ')', 1, 25)
from master.dbo.spt_monitor

select
    total_read = substring(convert(varchar(11), @total_read) + '(' +
        convert(varchar(11), @total_read - total_read) + ')', 1, 19),
    total_write = substring(convert(varchar(11), @total_write) + '(' +
        convert(varchar(11), @total_write - total_write) + ')', 1, 19),
    total_errors = substring(convert(varchar(11), @total_errors) + '(' +
        convert(varchar(11), @total_errors - total_errors) + ')', 1, 19),
    connections = substring(convert(varchar(11), @connections) + '(' +
        convert(varchar(11), @connections - connections) + ')', 1, 18)
from master.dbo.spt_monitor

/*
**  Now update spt_monitor
*/
update master.dbo.spt_monitor
    set
        lastrun = @now,
        cpu_busy = @cpu_busy,
        io_busy = @io_busy,
        idle = @idle,
        pack_received = @pack_received,
        pack_sent = @pack_sent,
        connections = @connections,
        pack_errors = @pack_errors,
        total_read = @total_read,
        total_write = @total_write,
        total_errors = @total_errors

return (0) -- sp_monitor
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

