## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_MShelptracertokens\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_MShelptracertokens**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -338290756 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@publisher| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@publisher_db| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@publication| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_MShelptracertokens\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_MShelptracertokens\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO

--
-- Name: 
--        sp_MShelptracertokens
-- 
-- Description: 
--        This procedure is used to retrieve the tracer token lsns.
--        It returns a list of the time a publisher_commit a tracer token along with the 
--        tracer token lsn which can be used when calling sp_MShelptracertokenhistory.
--  
-- Parameters: 
--        @publisher        sysname
--        @publisher_db    sysname
--        @publication    sysname                                
--
-- Returns: 
--        0 - succeeded
--      1 - failed
--
-- Result: 
--        (see description)
--
-- Security: 
--        DBO or replmonitor of distribution db (used by the UI)
-- Requires Certificate signature for catalog access
--
create procedure sys.sp_MShelptracertokens
(
    @publisher        sysname,
    @publisher_db    sysname,
    @publication    sysname
)
as
begin
    set nocount on
    
    declare @retcode            int,
            @publication_id        int,
            @distribution_db    sysname
    
    select @distribution_db = db_name()
    
    --
    -- security check.
    -- User must be member of 'replmonitor' role in distribution database
    --
    exec @retcode = sys.sp_MSrepl_DistributorReplMonitorAccess @distribution_db = @distribution_db
    if @retcode != 0 or @@error != 0
        return 1

    -- Has to be executed from distribution database
    if sys.fn_MSrepl_isdistdb (@distribution_db) != 1
    begin
        -- sp_MSispeertopeeragent can only be executed in the distribution database.
        raiserror (21482, 16, -1, 'sp_MShelptracertokens', 'distribution')
        return 1
    end
    
    -- check to see if the publication exists
    select @publication_id = msp.publication_id
        from dbo.MSpublications msp
            join sys.servers ss
                on msp.publisher_id = ss.server_id
        where UPPER(ss.name) = UPPER(@publisher)
            and msp.publisher_db = @publisher_db
            and msp.publication = @publication
                        
    if @publication_id is NULL
    begin
        -- Publication 'publication' does not exist.
        raiserror(21200, 16, -1, @publication)
        return 1
    end

    -- make sure to only return the tracer_ids 
    -- that have tracer history information.
    select tracer_id,
            publisher_commit
        from MStracer_tokens
        where publication_id = @publication_id
            and tracer_id in (select parent_tracer_id
                                    from MStracer_history)
        order by publisher_commit desc

    return 0
end
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

