## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_MSsetupnosyncsubwithlsnatdist_cleanup\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_MSsetupnosyncsubwithlsnatdist_cleanup**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -339359115 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@publisher| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@publisher_db| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@publication| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@article| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@artid| |int|4|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@subscriber| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@destination_db| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@next_valid_lsn| |binary|10|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_MSsetupnosyncsubwithlsnatdist_cleanup\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_MSsetupnosyncsubwithlsnatdist_cleanup\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO
--
-- Name: sp_MSsetupnosyncsubwithlsnatdist_cleanup
-- 
-- Description: try to revert the status change of MSsubscription during the execution
-- of MSsubscriptions for the article, and to remove the rows added for the subscription
-- in table MSnosyncsubsetup. The table itself will not be removed just in case it will be
-- used later soon. The cleanup process is in best-effor way, which does not run 
-- under a transaction.
--
-- Security: Procedural security check is performed inside this procedure to
--           ensure that the caller is a member of sysadmin. Execute 
--           permission of this procedure is granted to public. This procedure 
--           is invoked via RPC
--
create procedure sys.sp_MSsetupnosyncsubwithlsnatdist_cleanup
(
    @publisher                              sysname,
    @publisher_db                         sysname,
    @publication                            sysname,
    @article                                   sysname,
    @artid                                     int,
    @subscriber                             sysname,
    @destination_db                       sysname,
    @next_valid_lsn                       binary(10)
)
as
begin
    set nocount on
    declare @publisherid int,
            @subscriberid int,
            @publisher_database_id int,
            @publication_id int

    -- Security check 
    if (isnull(is_srvrolemember('sysadmin'),0) = 0)
    begin
        raiserror(21089, 16, -1)
        return 1
    end

    -- Obtain Publisher's server id
    select @publisherid = srvid 
      from master.dbo.sysservers
     where upper(srvname) = upper(@publisher) collate database_default
    if @@error&lt;&gt;0 goto Failure

    -- Obtain Subscriber's server id
    select @subscriberid = srvid
      from master.dbo.sysservers
     where upper(srvname) = upper(@subscriber) collate database_default
    if @@error&lt;&gt;0 goto Failure
            
    -- Find out what the publisher database id is
    select @publisher_database_id = id
      from dbo.MSpublisher_databases
     where publisher_db = @publisher_db
       and publisher_id = @publisherid
    if @@error&lt;&gt;0 goto Failure

    -- Obtain the publication id
    select @publication_id = publication_id
      from dbo.MSpublications
     where publisher_id = @publisherid
       and publisher_db = @publisher_db
       and publication = @publication
    if @@error&lt;&gt;0 goto Failure

    -- Deactivate subscriptions in dbo.MSsubscriptions
    update dbo.MSsubscriptions
       set status = 0 --inactive status
     where publisher_database_id = @publisher_database_id
       and publisher_id = @publisherid
       and publisher_db = @publisher_db
       and publication_id = @publication_id
       and subscriber_id = @subscriberid
       and subscriber_db = @destination_db
       and (@article = N'all' or article_id = @artid)
    if @@error&lt;&gt;0 goto Failure

    -- Delete the rows from MSnosyncsubsetup table regarding 
    -- the specified nonsync subscription; we do not remove 
    -- the table itself since it might be useful for future
    -- non-sync subscription.
    if object_id(N'dbo.MSnosyncsubsetup', 'U') is NOT NULL
    begin
        delete dbo.MSnosyncsubsetup 
        where publisher_database_id = @publisher_database_id
          and publication_id = @publication_id
          and artid = @artid
          and next_valid_lsn = @next_valid_lsn
    end
    if @@error&lt;&gt;0 goto Failure

    return 0

Failure:
    return 1
end
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

