## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_MSchange_logreader_agent_properties\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_MSchange_logreader_agent_properties**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -384296032 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@publisher| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@publisher_db| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@publisher_security_mode| |int|4|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@publisher_login| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@publisher_password| |nvarchar|524|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@job_login| |nvarchar|257|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@job_password| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@publisher_type| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_MSchange_logreader_agent_properties\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_MSchange_logreader_agent_properties\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO
create procedure sys.sp_MSchange_logreader_agent_properties
(
    @publisher                    sysname,
    @publisher_db                 sysname,
    @publisher_security_mode    int,
    @publisher_login            sysname,
    @publisher_password            nvarchar(524),
    @job_login                     nvarchar(257),
    @job_password                 sysname,
    @publisher_type                sysname
)
as
begin
    set nocount on
    
    declare @retcode         bit,
            @publisher_id     int,
            @agent_id        int,
            @agent_exists    bit,
            @job_id            uniqueidentifier,
            @job_step_uid    uniqueidentifier,
            @pubsecmode        int

    -- security: Has to be executed by SA of dist db
    if is_srvrolemember('sysadmin') != 1
    begin
        -- You do not have the required permissions to complete the operation.
        raiserror (20604, 16, -1)
        return 1
    end

    -- retrieve the publisher id
    select @publisher_id = server_id 
        from sys.servers 
        where upper(name) = upper(@publisher)
    if @publisher_id is null
    begin
        -- Publisher @publisher does not exist.
        raiserror(21618, 16, -1, @publisher)
        return 1
    end

    select @agent_id = id
        from MSlogreader_agents
        where publisher_id = @publisher_id
            and publisher_db = @publisher_db
    if @agent_id is NULL
    begin
        -- The logreader agent job for publisher (@publisher), database (@publisher_db), publication (@publication) could not be found.
        raiserror (21799, 16, -1, N'logreader', @publisher, @publisher_db, 'all')
        return 1
    end 
    
    begin transaction tran_sp_MSchange_logreader
    save transaction tran_sp_MSchange_logreader

    if @publisher_security_mode is not NULL
        or @publisher_login is not NULL
        or @publisher_password is not NULL
    begin
        -- if WINDOWS authentication then clear out the login/password
        if @publisher_security_mode = 1
        begin
            select @publisher_login = '',
                    @publisher_password = newid()
        end

        -- Encrypt the password before storing
        exec @retcode = sys.sp_MSreplencrypt @publisher_password OUTPUT
        if @@error &lt;&gt; 0 or  @retcode &lt;&gt; 0
            goto FAILED
        
        update MSlogreader_agents
            set publisher_security_mode = isnull(@publisher_security_mode, publisher_security_mode),
                publisher_login = isnull(@publisher_login, publisher_login),
                publisher_password = isnull(@publisher_password, publisher_password)
            where id = @agent_id
        if @@error &lt;&gt; 0
            goto FAILED
    end
    
    if @job_login is not NULL
        or @job_password is not NULL
    begin
        -- HETERO check only
        if @publisher_type != N'MSSQLSERVER'
        begin
            -- we can only allow @job_login change for Hetero when
            -- the publisher_security_mode is standard security...
            select @pubsecmode = security_mode
                from msdb..MSdistpublishers
                where name = @publisher
                    and distribution_db = db_name()

            if @pubsecmode is not NULL 
                AND @pubsecmode != 0
                AND @job_login is not NULL
            begin
                -- "@job_login can only be specified/changed for heterogeneous publications when the publisher security_mode (for sp_adddistpublisher) is set to 0."
                RAISERROR(21842, 16, -1, '@job_login', 'the publisher security_mode (for sp_adddistpublisher)', '0')
                goto FAILED
            end
        end
        
        exec @retcode = sys.sp_MSreplagentjobexists @type            = 2,
                                                    @exists         = @agent_exists output,
                                                    @job_id            = @job_id output,
                                                    @job_step_uid    = @job_step_uid output,
                                                    @publisher        = @publisher,
                                                    @publisher_db    = @publisher_db
        if @@error &lt;&gt; 0 or @retcode &lt;&gt; 0
            goto FAILED

        if @agent_exists = 0
        begin
            -- The logreader agent job for publisher (@publisher), database (@publisher_db), publication (@publication) could not be found.
            raiserror (21799, 16, -1, N'logreader', @publisher, @publisher_db, 'all')
            goto FAILED
        end
        
        exec @retcode = sys.sp_MSchange_repl_job @id = @job_id,
                                                @step_uid = @job_step_uid,
                                                @login = @job_login,
                                                @password = @job_password
        if @@error &lt;&gt; 0 or @retcode &lt;&gt; 0
            goto FAILED
    end

    commit transaction tran_sp_MSchange_logreader

    return 0
FAILED:
    rollback transaction tran_sp_MSchange_logreader
    commit transaction

    return 1
end
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

