## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_sqlagent_delete_job\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_sqlagent_delete_job**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -398287099 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@job_id| |uniqueidentifier|16|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_sqlagent_delete_job\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_sqlagent_delete_job\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO
CREATE PROCEDURE sys.sp_sqlagent_delete_job
    @job_id                UNIQUEIDENTIFIER
AS 
BEGIN 
    DECLARE @retval INT 

    -- Validate if current db context is supported
    EXEC @retval = sys.sp_sqlagent_verify_database_context
    IF (@retval &lt;&gt; 0)
    BEGIN
        RETURN(@retval)
    END


    -- If  job_id is null, then throw validation error
    IF(@job_id IS NULL)
    BEGIN
        RAISERROR(14262, -1, -1, '@job_id', 'NULL')
        RETURN(1) --Failure
    END

    DECLARE @TranCounter INT
    SET @TranCounter = @@TRANCOUNT
    IF (@TranCounter &gt; 0)
    BEGIN
        SAVE TRANSACTION tran_sqlagent_delete_job
    END
    ELSE
    BEGIN
        BEGIN TRANSACTION
    END

    BEGIN TRY
        -- Delete job  &amp; its references
        -- Delete job step logs
        DELETE sys.sqlagent_jobsteps_logs
        FROM sys.sqlagent_jobsteps_logs jl,  sys.sqlagent_jobsteps  js
        WHERE js.job_id = @job_id
        AND js.step_uid = jl.step_uid

        -- Delete job history logs
        DELETE  sys.sqlagent_job_history 
        WHERE job_id = @job_id

        -- Delete job steps related to this job
        DELETE sys.sqlagent_jobsteps 
        WHERE job_id = @job_id

        -- Delete job
        DELETE sys.sqlagent_jobs 
        WHERE job_id = @job_id

        IF (@TranCounter = 0)
        BEGIN
            COMMIT TRANSACTION
        END
        RETURN (0)

    END TRY
    BEGIN CATCH
        -- If there is no parent transaction  and current request has an active user transaction, 
        -- but an error has occurred then Rollback transaction
        IF (@TranCounter = 0 OR XACT_STATE() = -1)
        BEGIN
            ROLLBACK TRANSACTION
        END
        ELSE IF (XACT_STATE() = 1)  
        BEGIN
            -- current request has an active user transaction
            -- rollback transaction to save point
            ROLLBACK TRANSACTION tran_sqlagent_delete_job
        END

        DECLARE @ErrorMessage   NVARCHAR(4000);
        DECLARE @ErrorSeverity  INT;
        DECLARE @ErrorState     INT;
        DECLARE @ErrorNumber    INT;
        DECLARE @ErrorLine      INT;
        DECLARE @ErrorProcedure NVARCHAR(200);
        SELECT @ErrorLine = ERROR_LINE(),
               @ErrorSeverity = ERROR_SEVERITY(),
               @ErrorState = ERROR_STATE(),
               @ErrorNumber = ERROR_NUMBER(),
               @ErrorMessage = ERROR_MESSAGE(),
               @ErrorProcedure = ISNULL(ERROR_PROCEDURE(), '-');

        RAISERROR (14684, @ErrorSeverity, -1 , @ErrorNumber, @ErrorSeverity, @ErrorState, @ErrorProcedure, @ErrorLine, @ErrorMessage);

        RETURN(1) --Failure
    END CATCH
    
    -- Notify Sql Agent on job deletion
    EXECUTE @retval = master.dbo.xp_sqlagent_notify 
        N'J',
        @job_id,
        NULL,
        NULL,
        N'D',
        NULL,
        1,
        @@trancount,
        NULL

    RETURN(@retval) -- 0 means success 
END 
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

