## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_dropreplsymmetrickey\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_dropreplsymmetrickey**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -400868168 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@check_replication| |bit|1|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@throw_error| |bit|1|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_dropreplsymmetrickey\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_dropreplsymmetrickey\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO
--
-- Name: 
--    sp_dropreplsymmetrickey
-- 
-- Description: 
--    This procedure drops the following:
--        Database symmetric key based on a password seed
--        Database level certificate with associated asymmetric public/private keys
--        Database level scoped replication symetric key used for encrypting
--
-- Parameters: 
--    See the procedure definition.
--
-- Returns: 
--    0 - On success
--    1 - On Failure
--
-- Result: 
--    None
--
-- Security: 
--    Must be DBO to execute.
--
CREATE PROCEDURE sys.sp_dropreplsymmetrickey
(
    @check_replication bit = 0, 
    @throw_error bit = 1
)
AS
BEGIN
    DECLARE @error_number     int,
            @error_severity int,
            @error_state     int


    -- security check
    IF IS_MEMBER('db_owner') != 1
    BEGIN
        RAISERROR(21050, 14, -1)
        RETURN 1
    END

    IF @check_replication = 1
    BEGIN
        -- if requested we want to ensure that the current database is not :
        --        1) tran published
        --        2) tran subscriber
        --        3) merge published
        --        4) merge subscriber
        IF sys.fn_MSrepl_istranpublished(DB_NAME(), 1) = 1
            OR (OBJECT_ID(N'MSreplication_subscriptions', N'U') IS NOT NULL
                OR OBJECT_ID(N'MSsubscription_properties', N'U') IS NOT NULL)
            OR sys.fn_MSrepl_ismergepublished(DB_NAME()) = 1
            OR (OBJECT_ID(N'MSmerge_replinfo', N'U') IS NOT NULL
                OR OBJECT_ID(N'sysmergesubscriptions', N'U') IS NOT NULL
                OR OBJECT_ID(N'sysmergepublications', N'U') IS NOT NULL
                OR OBJECT_ID(N'MSsubscription_properties', N'U') IS NOT NULL)
        BEGIN
            RETURN 0
        END
    END
    
    BEGIN TRY
        DROP SYMMETRIC KEY SQLSERVER_REPLICATION
    END TRY
    BEGIN CATCH
        -- we eat the following error:
        --  Msg 15151, Level 16, State 1, Line 1
        --  Cannot drop the symmetric key 'SQLSERVER_REPLICATION', because it does not exist or you do not have permission.
        IF @@ERROR != 15151
        BEGIN
            IF @throw_error = 1
            BEGIN
                SELECT @error_number = ERROR_NUMBER(), 
                        @error_severity = ERROR_SEVERITY(), 
                        @error_state = ERROR_STATE()

                RAISERROR(@error_number, @error_severity, @error_state)
            END
            
            RETURN 1
        END
    END CATCH

    BEGIN TRY
        DROP CERTIFICATE SQLSERVER_REPLICATION
    END TRY
    BEGIN CATCH
        -- we eat the following error:
        --  Msg 15151, Level 16, State 1, Line 1
        --  Cannot drop the certificate 'SQLSERVER_REPLICATION', because it does not exist or you do not have permission.
        IF @@ERROR != 15151
        BEGIN
            IF @throw_error = 1
            BEGIN
                SELECT @error_number = ERROR_NUMBER(), 
                        @error_severity = ERROR_SEVERITY(), 
                        @error_state = ERROR_STATE()

                RAISERROR(@error_number, @error_severity, @error_state)
            END
            
            RETURN 1
        END
    END CATCH
    
    RETURN 0
END
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

