## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_MSrepl_IsLastPubInSharedSubscription\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_MSrepl_IsLastPubInSharedSubscription**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -46533585 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@subscriber| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@subscriber_db| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@publication| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_MSrepl_IsLastPubInSharedSubscription\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_MSrepl_IsLastPubInSharedSubscription\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO

--
-- Name:
--        sp_MSrepl_IsLastPubInSharedSubscription
--
-- Description:
--        Function to determine if the passed publication is the only
--      publication having a shared agent with a subscription 
--      at the given publisher/publisher database pair.  It is used
--      by the user interface to determine when the last publication
--      is being dropped and shared meta data at the subscriber can
--      be cleaned up.
--
--      This stored procedure is executed in the publishing database.
--      For heterogeneous publishers, it is executed in the distribution
--      database.
--
-- Returns:  A result set with a single integer value:
--        0 == FALSE  Other publications with shared agents exist for this publisher db/subscriber db pair
--        1 == TRUE    This is the only publication having a shared agent for this publisher db/subscriber db pair
--
-- Security:
--        public
-- Requires Certificate signature for catalog access
--
-- Notes:
--        Includes logic to determine if a db is being used as a distribution db
--
CREATE PROCEDURE sys.sp_MSrepl_IsLastPubInSharedSubscription
(
    @subscriber sysname,
    @subscriber_db sysname,
    @publication sysname
)
AS
BEGIN
    SET NOCOUNT ON
    
    DECLARE @fLastPub int,
            @retcode int
    
    -- Security check
    exec @retcode = sys.sp_MSreplcheck_publish
    IF @@error &lt;&gt; 0 or @retcode &lt;&gt; 0
        RETURN 1

    -- Check to see if database is activated for publication
    IF sys.fn_MSrepl_ispublished(db_name()) &lt;&gt; 1
    BEGIN
        -- "This database is not enabled for publication."
        RAISERROR (14013, 16, -1)
        RETURN 1
    END

    IF @subscriber IS NULL
    BEGIN
        -- The parameter @subscriber cannot be NULL.
        RAISERROR (14043, 16, -1, '@subscriber', 'fn_MSrepl_IsLastPubInSharedSubscription')
        RETURN 1
    END

    EXEC @retcode = sys.sp_validname @subscriber
    IF @@ERROR &lt;&gt; 0 OR @retcode &lt;&gt; 0
        RETURN 1
        
    IF @subscriber_db IS NULL
    BEGIN
        -- The parameter @subscriber_db cannot be NULL.
        RAISERROR (14043, 16, -1, '@subscriber_db', 'fn_MSrepl_IsLastPubInSharedSubscription')
        RETURN 1
    END

    EXEC @retcode = sys.sp_validname @subscriber_db
    IF @@ERROR &lt;&gt; 0 OR @retcode &lt;&gt; 0
        RETURN 1
        
    IF @publication IS NULL
    BEGIN
        -- The parameter @publication cannot be NULL.
        RAISERROR (14043, 16, -1, '@publication', 'fn_MSrepl_IsLastPubInSharedSubscription')
        RETURN 1
    END

    EXEC @retcode = sys.sp_validname @publication
    IF @@ERROR &lt;&gt; 0 OR @retcode &lt;&gt; 0
        RETURN 1
    
    SET @fLastPub = 0
    
    -- Verify that the passed publication is a publication for this publishing database
    -- that uses an independent agent and has a subscription at the specified
    -- subscriber / subscriber database pair.
    IF NOT EXISTS
    (
        SELECT    *
        FROM    syspublications p, sysarticles a, syssubscriptions s
        WHERE    p.pubid = a.pubid
          AND    a.artid = s.artid
          AND    p.independent_agent = 0
          AND    s.dest_db = @subscriber_db
          AND    s.srvname = UPPER(@subscriber) 
          AND    p.name = @publication
    )      
    BEGIN
        -- No shared agent subscription exists for publication '%s' and the subscriber/subscriber database pair '%s'/'%s'.
        RAISERROR (21426, 16, -1, '@publication', '@subscriber', 'subscriber_db')
        RETURN 1
    END
    
    IF NOT EXISTS
    (
        SELECT    *
        FROM    syspublications p, sysarticles a, syssubscriptions s
        WHERE    p.pubid = a.pubid
          AND    a.artid = s.artid
          AND    p.independent_agent = 0
          AND    s.dest_db = @subscriber_db
          AND    s.srvname = UPPER(@subscriber) 
          AND    p.name &lt;&gt; @publication
    )      
    BEGIN
        -- The passed publication is the only publication for this publishing database
        -- that uses an independent agent and has a subscription at the specified
        -- subscriber / subscriber database pair.
        SET @fLastPub = 1
    END

    SELECT @fLastPub
    RETURN 0
END
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

