## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_delete_backup\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_delete_backup**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -602825029 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@backup_url| |nvarchar|360|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@database_name| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_delete_backup\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_delete_backup\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO
create procedure sys.sp_delete_backup
(
    @backup_url            nvarchar(360),
    @database_name        sysname = null
)
as
begin
    set nocount on

    declare @hasAccess bit

    if @database_name is not null
    begin
        --
        -- If database exists, we are going to use the stored proc sys.sp_delete_backup_file_snapshot
        -- to delete snapshots which does the permissions check.
        --
        if not exists (select * from master.sys.databases where name = @database_name)
        begin
            raiserror(15010, 16, 1, @database_name)
            return 1
        end
    end
    else
    begin
        --
        -- Check whether the user has the ALTER ANY DATABASE permission
        --
        set @hasAccess = has_perms_by_name(null, null, 'alter any database')
        if @hasAccess = 0 OR @hasAccess IS NULL
        begin
            raiserror(14260, 16, -1)
            return 1
        end
    end

    --
    -- Create a table to store the o/p of restore filelistonly. This will need to be updated/modified
    -- everytime restore filelistonly is updated.
    --
    create table #filelist_table
    (
        LogicalName nvarchar(128),
        PhysicalName nvarchar(260),
        Type char(1),
        FileGroupName nvarchar(128),
        Size numeric(20,0),
        MaxSize numeric(20,0),
        FileId tinyint,
        CreateLSN numeric(25,0),
        DropLSN numeric(25, 0),
        UniqueID uniqueidentifier,
        ReadOnlyLSN numeric(25,0),
        ReadWriteLSN numeric(25,0),
        BackupSizeInBytes bigint,
        SourceBlockSize int,
        FileGroupId int,
        LogGroupGUID uniqueidentifier,
        DifferentialBaseLSN numeric(25,0),
        DifferentialBaseGUID uniqueidentifier,
        IsReadOnly bit,
        IsPresent bit,
        TDEThumbprint varbinary(32),
        SnapshotUrl nvarchar(360)
    )

    begin try
        insert into #filelist_table
        EXEC ('restore filelistonly from URL = ''' + @backup_url + '''')
    end try
    begin catch
        throw
        return 1
    end catch

    declare cursor_filelist cursor for
        select SnapshotUrl from #filelist_table

    DECLARE @ErrorMessage NVARCHAR(4000);
    declare @retval INT
    declare @finalret INT
    declare @snapshot_url nvarchar(360)
    set @snapshot_url = ''
    set @finalret = 0

    --
    -- Iterate over the snapshot list and try to delete them
    --
    open cursor_filelist
    fetch next from cursor_filelist into @snapshot_url
    while @@Fetch_Status = 0
    begin
        if @database_name is not null
        begin
            --
            -- Use sys.sp_delete_backup_file_snapshot to delete the snapshot which checks for
            -- the ALTER (ANY) DATABASE permission
            --
            begin try
            exec @retval = sys.sp_delete_backup_file_snapshot @database_name, @snapshot_url
            end try
            begin catch
                set @retval = ERROR_NUMBER();
                set @ErrorMessage = ERROR_MESSAGE();
                raiserror (@ErrorMessage, -1, -1)
            end catch
        end
        else
        begin
            --
            -- Delete the snapshot directly
            --
            begin try
                exec %%Device().DeleteFile(PhysicalName = @snapshot_url)
                set @retval = @@error
            end try
            begin catch
                set @retval = ERROR_NUMBER();
                set @ErrorMessage = ERROR_MESSAGE();
                raiserror (@ErrorMessage, -1, -1)
            end catch
        end

        if @retval &lt;&gt; 0
            set @finalret = @retval

        fetch next from cursor_filelist into @snapshot_url
    end

    drop table #filelist_table

    --
    -- Delete the backup file only if deleting all of the snapshot succeeded
    --
    if @finalret = 0
        EXEC %%Device().DeleteFile(PhysicalName = @backup_url)
    else
        raiserror ('Backup file %ls has not been deleted because at least one file snapshot referenced by it could not be deleted.', -1, -1, @backup_url)

    return @finalret
end
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

