## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_helpdatatypemap\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_helpdatatypemap**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -628298262 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@source_dbms| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@source_version| |varchar|10|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@source_type| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@destination_dbms| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@destination_version| |varchar|10|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@destination_type| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@defaults_only| |bit|1|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
|Name |Datatype |Max length |
|-|-|-|
|mapping_id|int|4|
|source_dbms|nvarchar|257|
|source_type|nvarchar|1024|
|destination_dbms|nvarchar|259|
|destination_type|nvarchar|1024|
|dataloss|bit|1|
|is_default|bit|1|

---
### Objects that depend on \[sys\].\[sp_helpdatatypemap\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_helpdatatypemap\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO

--
-- Name:
--        sp_helpdatatypemap
--
-- Description:
--        Retrieve data type map as result set
--
-- Returns:
--        0 if successful
--        1 if failed
--
-- Security:
--        public
--
-- Notes:
--        Produces the full data type map based on input
--        parameters.  Includes filtered version based
--        on source and destination dbms, and defaults.
--

CREATE PROCEDURE sys.sp_helpdatatypemap
(
    @source_dbms            sysname,
    @source_version            varchar(10)    = '%',
    @source_type            sysname        = '%',
    @destination_dbms        sysname        = '%',
    @destination_version    varchar(10)    = '%',
    @destination_type        sysname        = '%',
    @defaults_only            bit            = 0
)
AS
BEGIN
    DECLARE @retcode int
    
    --
    -- Security Check.
    --
    EXEC @retcode = sys.sp_MSreplcheck_publish
    IF @@ERROR &lt;&gt; 0 or @retcode &lt;&gt; 0
    BEGIN
        RETURN(1)
    END

    SELECT    hdm.mapping_id as [mapping_id],
            hdm.source_dbms + 
            case
                when hdm.source_version is not null then ' ' + hdm.source_version
                else ''
            end as [source_dbms],
            sys.fn_MSrepl_sourcetype
            (
                hdm.source_type,
                hdm.source_length_min,
                hdm.source_length_max,
                hdm.source_precision_min,
                hdm.source_precision_max,
                hdm.source_scale_min,
                hdm.source_scale_max,
                hdm.source_createparams
            ) as [source_type],
            hdm.destination_dbms +
            case
                when hdm.destination_version is not null then ' (' + hdm.destination_version + ')'
                else ''
            end as [destination_dbms],
            sys.fn_MSrepl_sourcetype
            (
                hdm.destination_type,
                case hdm.destination_length
                    when -1 then hdm.source_length_min
                    else hdm.destination_length
                end,
                case hdm.destination_length
                    when -1 then hdm.source_length_max
                    else hdm.destination_length
                end,
                case hdm.destination_precision
                    when -1 then hdm.source_precision_min
                    else hdm.destination_precision
                end,
                case hdm.destination_precision
                    when -1 then hdm.source_precision_max
                    else hdm.destination_precision
                end,
                case hdm.destination_scale
                    when -1 then hdm.source_scale_min
                    else hdm.destination_scale
                end,
                case hdm.destination_scale
                    when -1 then hdm.source_scale_max
                    else hdm.destination_scale
                end,
                hdm.destination_createparams
            )
            as [destination_type],
            hdm.dataloss as [dataloss],
            hdm.is_default as [is_default]
    FROM    sys.fn_helpdatatypemap
            (
                @source_dbms,
                @source_version,
                @source_type,
                @destination_dbms,
                @destination_version,
                @destination_type,
                @defaults_only
            ) hdm
    ORDER BY    [source_dbms],
                [source_version],
                [destination_dbms],
                [destination_version],
                [source_type],
                [is_default] desc,
                [destination_type]

    RETURN (0)
END
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

