## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_MSadd_tracer_token\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_MSadd_tracer_token**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -756626989 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@publisher| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@publisher_db| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@publication| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@tracer_id| |int|4|Input/output or output|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@subscribers_found| |bit|1|Input/output or output|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_MSadd_tracer_token\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_MSadd_tracer_token\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO
--
-- Name: 
--        sp_MSadd_tracer_token
-- 
-- Description: 
--        This procedure will log the parent tracer record token row (MStracer_tokens).
--        A tracer record parent token row is defined as the record which 
--        tracks the amount of time it took from when the tracer was inserted 
--        into the log to when the logreader picked it up and inserted it into
--        at the distribution database. We call it the parent because there is
--        there is only one per tracer token inserted into the publisher.
--  
-- Parameters: 
--        @publisher            sysname            publisher name
--        @publisher_db        sysname            publisher database
--        @publication        sysname            publication
--        @tracer_id            int                outputs the newly inserted tracer token id
--
-- Returns: 
--        0 - succeeded
--      1 - failed
--
-- Result: 
--        None
--
-- Security: 
--        Sysadmin (never run by dist agent)
-- Requires Certificate signature for catalog access
--
create procedure sys.sp_MSadd_tracer_token
(
    @publisher            sysname,
    @publisher_db        sysname,
    @publication        sysname,
    @tracer_id            int output,
    @subscribers_found    bit = 0 output
)
as
begin
    set nocount on

    declare @retcode                 int,
            @publication_id            int,
            @SNAPSHOT_PUB            int

    --    
    -- security check
    -- only sysadmin can execute this
    --
    if (isnull(is_srvrolemember('sysadmin'),0) = 0) 
    begin
        raiserror(21089, 16, -1)
        return (1)
    end
    
    select @retcode                 = 0,
            @publication_id            = NULL,
            @tracer_id                = NULL,
            @SNAPSHOT_PUB            = 1,
            @subscribers_found        = 0
            
    -- retrieve the publication id and ensure no snapshot pub is selected
     select @publication_id = msp.publication_id
        from dbo.MSpublications msp
            join sys.servers ss
                on msp.publisher_id = ss.server_id
        where UPPER(ss.name) = UPPER(@publisher)
            and msp.publisher_db = @publisher_db
            and msp.publication = @publication
            and msp.publication_type &lt;&gt; @SNAPSHOT_PUB

    if @publication_id is NULL
    begin 
        -- Publication 'publication' does not exist.
        raiserror(21200, 16, -1, @publication)
        return 1
    end

    -- check if there are any active distribution agents for.
    if not exists(select * 
                    from sys.fn_activedistributionagentids(@publication_id))
    begin
        return 0
    end

    -- now we know that we have subscribers
    select @subscribers_found = 1

    begin transaction tr_sp_MSadd_tracer_token
    save transaction tr_sp_MSadd_tracer_token
    
    -- now perform an insert for the tracer token
    insert into MStracer_tokens
        (
            publication_id,
            publisher_commit
        ) values 
        (
            @publication_id,
            getdate()
        )
    if @@error &lt;&gt; 0
        goto Err_Handler

    -- set the output tracer_id value
    select @tracer_id = scope_identity()
    
    commit transaction tr_sp_MSadd_tracer_token
    
    return 0

Err_Handler:
    rollback transaction tr_sp_MSadd_tracer_token
    commit transaction 
 
    return 1
end
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

