## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_MSacquireHeadofQueueLock\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_MSacquireHeadofQueueLock**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -819689368 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@process_name| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@queue_timeout| |int|4|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@no_result| |bit|1|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@return_immediately| |bit|1|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@DbPrincipal| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_MSacquireHeadofQueueLock\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_MSacquireHeadofQueueLock\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO

create procedure sys.sp_MSacquireHeadofQueueLock
@process_name                   sysname,
@queue_timeout                  int = 0,  -- means wait in definitely
@no_result                      bit = 0,
@return_immediately             bit = 0,  -- if 1, do not wait: return and 
                                          -- post a progress message.
@DbPrincipal                    sysname = NULL
AS
declare @entry_date     datetime
declare @delay_time     int --in second
declare @retcode        int
declare @max_waiting    int
declare @lock_acquired  bit

-- Security Checking 
-- sysadmin or db_owner or PAL user of some publication have access
exec @retcode = sys.sp_MSrepl_PAL_rolecheck
if (@retcode &lt;&gt; 0) or (@@error &lt;&gt; 0)
begin
        RAISERROR (14126, 11, -1)
       return 1
end

if @queue_timeout&lt;0
    begin
        raiserror(21344, 16, -1, '@queue_timeout')
        return (1)      
    end
        
if @queue_timeout&gt; 3600*12 -- more than 12 hours is not allowed: 
                           -- make it 0 in this case.
    begin
        raiserror(21417, 16, -1) 
        return (1)
    end

if @DbPrincipal is NULL 
begin
    if exists (select * from sys.database_principals where name=N'MSmerge_PAL_role' and type = 'R')
        select @DbPrincipal = N'MSmerge_PAL_role'
    else
        select @DbPrincipal = N'db_owner'
end


--quick peek and leave
if @return_immediately=1
    begin
        --take a peek: return without wait regardless of whether the lock 
        --is successfully acquired.
        exec @retcode=sys.sp_getapplock @Resource=@process_name,
            @LockMode=N'Exclusive',@LockOwner='Session',@LockTimeout=0,
            @DbPrincipal = @DbPrincipal
        if (@retcode &lt;&gt; 0 AND @retcode &lt;&gt; -1)
            begin
                RAISERROR(21414,16,-1)
                RETURN(@retcode)
            end
        IF (@retcode = 0)       -- AppLock acquired
            select 1, 0         -- 1 means lock acquired, 0 is the time 
                                -- consumed to acquired this lock.
        else if @retcode = -1   -- AppLock is not available 
            select 0, 0         -- first 0 means lock not available, 
                                -- second column will be ignored.
        return (0)              -- OK
    end     

-- from now on, @return_immediately=0
-- if @queue_timeout=0, means waiting indefinitely
if @queue_timeout=0
    select @max_waiting = NULL
else
--otherwise convert to minisecond and pass it down.
    select @max_waiting = @queue_timeout * 1000


select @delay_time=0
select @entry_date=getdate()

-- First try to acquire EXCLUSIVE lock which signfies at front of queue.
-- i.e. I'm next.

exec @retcode=sys.sp_getapplock @process_name, @LockMode=N'Exclusive',
    @LockOwner=N'Session', @LockTimeout=@max_waiting, @DbPrincipal=@DbPrincipal

-- We shouldn't return from above until we have it 
-- RC should be either 0 (got immediately) or 1 (waited and got it eventually) or -1 (timed out); Exit on anything else.
-- We need value -1 because @LockTimeout value is no longer NULL, 
-- meaning waiting indefinitely. It is possible 
-- that we waited for a given length of time and timed out
IF (@retcode &lt;&gt; 0 and @retcode &lt;&gt; 1) and @retcode&lt;&gt;-1
    BEGIN
        RAISERROR(21413, 16, -1)
        RETURN(@retcode)
    END
    
-- Im-first lock is to be released after successfully 
-- obtained a slot lock later.
select @delay_time=datediff(ss, @entry_date, getdate())
if @retcode=-1
    select @lock_acquired=0
else
    select @lock_acquired=1

if @no_result = 0
begin
    select @lock_acquired, @delay_time
end

RETURN(0)
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

