## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_expired_subscription_cleanup\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_expired_subscription_cleanup**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -848733509 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@publisher| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_expired_subscription_cleanup\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_expired_subscription_cleanup\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO
 
CREATE PROCEDURE sys.sp_expired_subscription_cleanup
(
    @publisher sysname = NULL
)
AS
BEGIN
    declare    @retcode            int,
            @db_name            sysname,
            @publisher_type        sysname,
            @category            int,
            @proc_name            nvarchar(200),
            @distributor        sysname,
            @distribdb            sysname,
            @distproc            nvarchar(300),
            @IsDistNULL            bit = 0,
            @IsPublished        bit = 0

    -- Security Check is done in called procedures

    -- Get distribution server information for remote RPC call.
    EXEC @retcode = sys.sp_MSrepl_getdistributorinfo @publisher      = @publisher,
                                                     @rpcsrvname     = @distributor OUTPUT,
                                                     @distribdb      = @distribdb OUTPUT,
                                                     @publisher_type = @publisher_type OUTPUT

    IF (@@ERROR != 0 OR @retcode != 0)
    BEGIN
        RETURN (@retcode)
    END

    IF (@distributor IS NULL OR @distribdb IS NULL)
    BEGIN
        SELECT @IsDistNULL = 1
        IF EXISTS (SELECT name FROM sys.databases WHERE sys.fn_MSrepl_ispublished(name) = 1)
        BEGIN
            SELECT @IsPublished = 1
        END
    END

    IF (@publisher_type != N'MSSQLSERVER')
    BEGIN
        -- Heterogeneous publisher subscription cleanup
        IF (@IsDistNULL = 0)
        BEGIN
            SELECT @proc_name = @distribdb + N'.sys.sp_MSdrop_expired_subscription'
            EXEC @retcode = @proc_name    @publisher = @publisher
        END
    END
    ELSE
    BEGIN
        -- SQL publisher - sweep all the published databases and distribution databases
        DECLARE DC CURSOR LOCAL FAST_FORWARD for
        SELECT DISTINCT name, category
        FROM   master.dbo.sysdatabases 
        WHERE ((category &amp; 4) = 4
           OR (category &amp; 1 = 1)
           OR (category &amp; 16 = 16))
            and databasepropertyex(name, 'Updateability') = 'READ_WRITE'
           and has_dbaccess(name) = 1
        FOR READ ONLY
        
        OPEN DC
        FETCH DC INTO @db_name, @category
        
        WHILE (@@fetch_status != -1)
        BEGIN
            -- Merge publication db
            IF (@category &amp; 4 = 4 and @IsDistNULL = 0)
            BEGIN
                SELECT @proc_name = @db_name + '.sys.sp_MSdrop_expired_mergesubscription'
                EXEC @retcode = @proc_name
                
                IF (@retcode != 0 OR @@ERROR != 0)
                BEGIN
                    GOTO DONE
                END
            END

            -- Tran publication db
            IF (@category &amp; 1 = 1 and @IsDistNULL = 0)
            BEGIN
                SELECT @proc_name = @db_name + '.sys.sp_MSdrop_expired_subscription'
                EXEC @retcode = @proc_name
                
                IF (@retcode != 0 OR @@ERROR != 0)
                BEGIN
                    goto DONE
                END
            END   
            
            --Distribution DB
            IF (@category &amp; 16 = 16 and @IsDistNULL = 0)
            BEGIN
                -- Deactivate any subscriptions which have been inactive beyond the maximum retention
                SELECT @proc_name = @db_name + '.dbo.sp_MSsubscription_cleanup'
                EXEC @retcode = @proc_name
                IF (@retcode != 0 OR @@ERROR != 0)
                BEGIN
                    goto DONE
                END
            END 

            FETCH DC INTO @db_name, @category
        END

        IF (@IsDistNULL = 1)
        BEGIN
            IF (@IsPublished = 1)
            BEGIN
                RAISERROR (20036, 16, -1)
                SELECT @retcode = 1
                goto DONE
            END
            ELSE
            BEGIN
                SELECT @retcode = 0
                goto DONE
            END
        END
        --
        -- sp_MScleanup_agent_entry in distribution database is called to periodically remove obselete
        -- entries in MSmerge_agents, which may be caused by the following reasons:
        --  1. publishing database is externally removed; therefore cleanup agent can not do its job
        --  2. Entries for anonymous merge subscriptions
        --
        SELECT @distproc = QUOTENAME(RTRIM(@distributor)) + '.' + QUOTENAME(RTRIM(@distribdb)) + '..sp_MScleanup_agent_entry'
        EXEC @retcode = @distproc 
        
        IF (@@ERROR != 0 OR @retcode != 0)
        BEGIN
            goto DONE
        END

DONE:
        -- Cursor cleanup
        CLOSE DC
        DEALLOCATE DC
    END

    RETURN @retcode
END
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

