## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[sys\].\[sp_IHXactSetJob\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **sys.sp_IHXactSetJob**

---
###  Description  




---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[sys\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/4.md) |
| Owner | \[sys\] |
| Creation date | 10/21/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | -992023206 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@publisher| |sysname|128|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@enabled| |bit|1|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@interval| |int|4|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@threshold| |int|4|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@LRinterval| |int|4|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@LRthreshold| |int|4|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[sys\].\[sp_IHXactSetJob\]
 No dependencies exist

---
### Objects that \[sys\].\[sp_IHXactSetJob\] depends on
 No dependencies exist

---
### Column level dependencies
 No dependencies exist

---
###  Permissions
No permissions defined

---
###  Extended properties  
No extended properties defined

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO

--
-- Name:
--        sp_IHXactSetJob
--
-- Description:
--        Manage the Oracle Poll Job used to force polling intervals
--        when the number of monitored changes exceeds a defined
--        threshold.
--
-- Inputs:
--        @publisher        == name of Oracle publisher
--        @enabled        == enabled flag
--        @interval        == minutes between Poll Job executions
--        @threshold        == number of changes to be exceeded
--                           prior to forcing new poll interval.
--        @LRinterval        == minutes between Poll Job executions
--                         when log reder is active
--        @LRthreshold    == number of changes to be exceeded
--                           prior to forcing new poll interval
--                         when log reader is active
--
-- Returns:
--        Return code (0 for success, 1 for failure)
--
-- Security:
--        public -- call must be sysadmin
--
-- Notes:
--        This stored procedure is provided so that the administrator of Oracle
--        publishing can activate, deactivate, and modify the parameters that
--        configure the execution of the Poll Job run at the Oracle database.
--      The settings are retained at the publisher in HREPL_XactSetJob.
--      All parameters default to NULL.  NULL parameters are not reset at the
--      publisher.
--

CREATE PROCEDURE sys.sp_IHXactSetJob
(
    @publisher        sysname,
    @enabled        bit = NULL,
    @interval        int = NULL,
    @threshold        int = NULL,
    @LRinterval        int = NULL,
    @LRthreshold    int = NULL
)
AS
BEGIN
    DECLARE @cmd            nvarchar(4000)
    DECLARE @retcode        int
    DECLARE @publisher_type    sysname

    --
    -- Security Check: require sysadmin
    --
    IF (ISNULL(IS_SRVROLEMEMBER('sysadmin'),0) = 0)
    BEGIN
        RAISERROR(21089,16,-1) 
        RETURN (1)
    END

    SET @retcode = 0

    EXEC @retcode = sys.sp_MSrepl_getpublisherinfo    @publisher        = @publisher,
                                                    @rpcheader        = @cmd OUTPUT,
                                                    @publisher_type    = @publisher_type OUTPUT,
                                                    @hreplOnly        = 1
    
    IF @retcode &lt;&gt; 0
        RETURN (@retcode)

    -- Error if the publisher is not an Oracle publisher
    IF @publisher_type NOT LIKE 'ORACLE%'
    BEGIN
        RAISERROR (21696, 16, -1, @publisher, @publisher_type)
            RETURN (1)
    END

    set @cmd = @cmd + N'sys.sp_ORAXactSetJob'
    
    EXEC @retcode = @cmd    @publisher,
                @enabled,
                @interval,
                @threshold,
                @LRinterval,
                @LRthreshold
    RETURN (@retcode)
END
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

