## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[dbo\].\[uspGetBillOfMaterials\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **uspGetBillOfMaterials**

---
###  Description  
 Stored procedure using a recursive query to return a multi-level bill of material for the specified ProductID. 



---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[dbo\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/1.md) |
| Owner | [\[dbo\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Users/1.md) |
| Creation date | 11/16/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | 1501248403 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@StartProductID|Input parameter for the stored procedure uspGetBillOfMaterials. Enter a valid ProductID from the Production.Product table.|int|4|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|
|@CheckDate|Input parameter for the stored procedure uspGetBillOfMaterials used to eliminate components not used after that date. Enter a valid date.|datetime|8|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
|Name |Datatype |Max length |
|-|-|-|
|ProductAssemblyID|int|4|
|ComponentID|int|4|
|ComponentDesc|nvarchar|50|
|TotalQuantity|decimal|17|
|StandardCost|money|8|
|ListPrice|money|8|
|BOMLevel|smallint|2|
|RecursionLevel|int|4|

---
### Objects that depend on \[dbo\].\[uspGetBillOfMaterials\]
 No dependencies exist

---
### Objects that \[dbo\].\[uspGetBillOfMaterials\] depends on
|Object name|Object type|Dep level|
|-|-|-|
|[\[Production\].\[BillOfMaterials\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/821577965.md)|Table|1|
|[\[Production\].\[Product\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/146099561.md)|Table|1|

 Total 2 object(s)

---
### Column level dependencies
|Object name|Column|Object type|
|-|-|-|
|[\[Production\].\[BillOfMaterials\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/821577965.md)|ComponentID|Table|
|[\[Production\].\[BillOfMaterials\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/821577965.md)|ProductAssemblyID|Table|
|[\[Production\].\[BillOfMaterials\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/821577965.md)|PerAssemblyQty|Table|
|[\[Production\].\[BillOfMaterials\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/821577965.md)|BOMLevel|Table|
|[\[Production\].\[BillOfMaterials\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/821577965.md)|StartDate|Table|
|[\[Production\].\[BillOfMaterials\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/821577965.md)|EndDate|Table|
|[\[Production\].\[Product\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/146099561.md)|ProductID|Table|
|[\[Production\].\[Product\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/146099561.md)|Name|Table|
|[\[Production\].\[Product\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/146099561.md)|StandardCost|Table|
|[\[Production\].\[Product\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/146099561.md)|ListPrice|Table|

 Total 10 column(s)

---
### Graphical dependencies
Click [here](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Procedures/1501248403_gr.md) to view dependencies graphically

---
###  Permissions
No permissions defined

---
###  Extended properties  
|Name |Value |
|-|-|
|MS_Description|Stored procedure using a recursive query to return a multi-level bill of material for the specified ProductID.|

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [dbo].[uspGetBillOfMaterials]
    @StartProductID [int],
    @CheckDate [datetime]
AS
BEGIN
    SET NOCOUNT ON;

    -- Use recursive query to generate a multi-level Bill of Material (i.e. all level 1 
    -- components of a level 0 assembly, all level 2 components of a level 1 assembly)
    -- The CheckDate eliminates any components that are no longer used in the product on this date.
    WITH [BOM_cte]([ProductAssemblyID], [ComponentID], [ComponentDesc], [PerAssemblyQty], [StandardCost], [ListPrice], [BOMLevel], [RecursionLevel]) -- CTE name and columns
    AS (
        SELECT b.[ProductAssemblyID], b.[ComponentID], p.[Name], b.[PerAssemblyQty], p.[StandardCost], p.[ListPrice], b.[BOMLevel], 0 -- Get the initial list of components for the bike assembly
        FROM [Production].[BillOfMaterials] b
            INNER JOIN [Production].[Product] p 
            ON b.[ComponentID] = p.[ProductID] 
        WHERE b.[ProductAssemblyID] = @StartProductID 
            AND @CheckDate &gt;= b.[StartDate] 
            AND @CheckDate &lt;= ISNULL(b.[EndDate], @CheckDate)
        UNION ALL
        SELECT b.[ProductAssemblyID], b.[ComponentID], p.[Name], b.[PerAssemblyQty], p.[StandardCost], p.[ListPrice], b.[BOMLevel], [RecursionLevel] + 1 -- Join recursive member to anchor
        FROM [BOM_cte] cte
            INNER JOIN [Production].[BillOfMaterials] b 
            ON b.[ProductAssemblyID] = cte.[ComponentID]
            INNER JOIN [Production].[Product] p 
            ON b.[ComponentID] = p.[ProductID] 
        WHERE @CheckDate &gt;= b.[StartDate] 
            AND @CheckDate &lt;= ISNULL(b.[EndDate], @CheckDate)
        )
    -- Outer select from the CTE
    SELECT b.[ProductAssemblyID], b.[ComponentID], b.[ComponentDesc], SUM(b.[PerAssemblyQty]) AS [TotalQuantity] , b.[StandardCost], b.[ListPrice], b.[BOMLevel], b.[RecursionLevel]
    FROM [BOM_cte] b
    GROUP BY b.[ComponentID], b.[ComponentDesc], b.[ProductAssemblyID], b.[BOMLevel], b.[RecursionLevel], b.[StandardCost], b.[ListPrice]
    ORDER BY b.[BOMLevel], b.[ProductAssemblyID], b.[ComponentID]
    OPTION (MAXRECURSION 25) 
END;
GO
EXEC sp_addextendedproperty N'MS_Description', N'Stored procedure using a recursive query to return a multi-level bill of material for the specified ProductID.', 'SCHEMA', N'dbo', 'PROCEDURE', N'uspGetBillOfMaterials', NULL, NULL
GO
EXEC sp_addextendedproperty N'MS_Description', N'Input parameter for the stored procedure uspGetBillOfMaterials. Enter a valid ProductID from the Production.Product table.', 'SCHEMA', N'dbo', 'PROCEDURE', N'uspGetBillOfMaterials', 'PARAMETER', N'@StartProductID'
GO
EXEC sp_addextendedproperty N'MS_Description', N'Input parameter for the stored procedure uspGetBillOfMaterials used to eliminate components not used after that date. Enter a valid date.', 'SCHEMA', N'dbo', 'PROCEDURE', N'uspGetBillOfMaterials', 'PARAMETER', N'@CheckDate'
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

