## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[dbo\].\[uspGetEmployeeManagers\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **uspGetEmployeeManagers**

---
###  Description  
 Stored procedure using a recursive query to return the direct and indirect managers of the specified employee. 



---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[dbo\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/1.md) |
| Owner | [\[dbo\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Users/1.md) |
| Creation date | 11/16/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | 1517248460 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@BusinessEntityID|Input parameter for the stored procedure uspGetEmployeeManagers. Enter a valid BusinessEntityID from the HumanResources.Employee table.|int|4|Input|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
|Name |Datatype |Max length |
|-|-|-|
|RecursionLevel|int|4|
|BusinessEntityID|int|4|
|FirstName|nvarchar|50|
|LastName|nvarchar|50|
|OrganizationNode|nvarchar|4000|
|ManagerFirstName|nvarchar|50|
|ManagerLastName|nvarchar|50|

---
### Objects that depend on \[dbo\].\[uspGetEmployeeManagers\]
 No dependencies exist

---
### Objects that \[dbo\].\[uspGetEmployeeManagers\] depends on
|Object name|Object type|Dep level|
|-|-|-|
|[\[HumanResources\].\[Employee\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/1557580587.md)|Table|1|
|[\[Person\].\[Person\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/2085582468.md)|Table|1|

 Total 2 object(s)

---
### Column level dependencies
|Object name|Column|Object type|
|-|-|-|
|[\[HumanResources\].\[Employee\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/1557580587.md)|BusinessEntityID|Table|
|[\[HumanResources\].\[Employee\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/1557580587.md)|OrganizationNode|Table|
|[\[HumanResources\].\[Employee\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/1557580587.md)|JobTitle|Table|
|[\[Person\].\[Person\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/2085582468.md)|BusinessEntityID|Table|
|[\[Person\].\[Person\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/2085582468.md)|FirstName|Table|
|[\[Person\].\[Person\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/2085582468.md)|LastName|Table|

 Total 6 column(s)

---
### Graphical dependencies
Click [here](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Procedures/1517248460_gr.md) to view dependencies graphically

---
###  Permissions
No permissions defined

---
###  Extended properties  
|Name |Value |
|-|-|
|MS_Description|Stored procedure using a recursive query to return the direct and indirect managers of the specified employee.|

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [dbo].[uspGetEmployeeManagers]
    @BusinessEntityID [int]
AS
BEGIN
    SET NOCOUNT ON;

    -- Use recursive query to list out all Employees required for a particular Manager
    WITH [EMP_cte]([BusinessEntityID], [OrganizationNode], [FirstName], [LastName], [JobTitle], [RecursionLevel]) -- CTE name and columns
    AS (
        SELECT e.[BusinessEntityID], e.[OrganizationNode], p.[FirstName], p.[LastName], e.[JobTitle], 0 -- Get the initial Employee
        FROM [HumanResources].[Employee] e 
            INNER JOIN [Person].[Person] as p
            ON p.[BusinessEntityID] = e.[BusinessEntityID]
        WHERE e.[BusinessEntityID] = @BusinessEntityID
        UNION ALL
        SELECT e.[BusinessEntityID], e.[OrganizationNode], p.[FirstName], p.[LastName], e.[JobTitle], [RecursionLevel] + 1 -- Join recursive member to anchor
        FROM [HumanResources].[Employee] e 
            INNER JOIN [EMP_cte]
            ON e.[OrganizationNode] = [EMP_cte].[OrganizationNode].GetAncestor(1)
            INNER JOIN [Person].[Person] p 
            ON p.[BusinessEntityID] = e.[BusinessEntityID]
    )
    -- Join back to Employee to return the manager name 
    SELECT [EMP_cte].[RecursionLevel], [EMP_cte].[BusinessEntityID], [EMP_cte].[FirstName], [EMP_cte].[LastName], 
        [EMP_cte].[OrganizationNode].ToString() AS [OrganizationNode], p.[FirstName] AS 'ManagerFirstName', p.[LastName] AS 'ManagerLastName'  -- Outer select from the CTE
    FROM [EMP_cte] 
        INNER JOIN [HumanResources].[Employee] e 
        ON [EMP_cte].[OrganizationNode].GetAncestor(1) = e.[OrganizationNode]
        INNER JOIN [Person].[Person] p 
        ON p.[BusinessEntityID] = e.[BusinessEntityID]
    ORDER BY [RecursionLevel], [EMP_cte].[OrganizationNode].ToString()
    OPTION (MAXRECURSION 25) 
END;
GO
EXEC sp_addextendedproperty N'MS_Description', N'Stored procedure using a recursive query to return the direct and indirect managers of the specified employee.', 'SCHEMA', N'dbo', 'PROCEDURE', N'uspGetEmployeeManagers', NULL, NULL
GO
EXEC sp_addextendedproperty N'MS_Description', N'Input parameter for the stored procedure uspGetEmployeeManagers. Enter a valid BusinessEntityID from the HumanResources.Employee table.', 'SCHEMA', N'dbo', 'PROCEDURE', N'uspGetEmployeeManagers', 'PARAMETER', N'@BusinessEntityID'
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

