## ![](../../../../Images32x32Metro/OBJECT_PROCEDURE.png "") Procedure:\[AdventureWorks2016CTP3\].\[dbo\].\[uspLogError\]
[Table of contents](../../../../index.md) > [Database engines](../../../../srv_index.md) > [(local)](../../../../DbEngine/(local)/db_index.md) > [AdventureWorks2016CTP3](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index.md) > [Objects by type](../../../../DbEngine/(local)/AdventureWorks2016CTP3/db_object_index_type_Objects%20by%20type.md) > [Procedures](../../../../DbEngine/(local)/AdventureWorks2016CTP3/procedures.md) > **uspLogError**

---
###  Description  
 Logs error information in the ErrorLog table about the error that caused execution to jump to the CATCH block of a TRY...CATCH construct. Should be executed from within the scope of a CATCH block otherwise it will return without inserting error information. 



---
### Procedure properties
| Name | Value |
|-|-|
| Schema | [\[dbo\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Schemas/1.md) |
| Owner | [\[dbo\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Users/1.md) |
| Creation date | 10/23/2015 |
| Type | P |
| Encrypted |![](../../../../ImagesMetro/RED_CROSS.gif "")|
| ID | 661577395 |
| Implementation type | Transact SQL |
| Is native compiled |![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Creation options
|Name|Value|
|-|-|
|QUOTED_IDENTIFIER|ON|
|ANSI_NULLS|ON|

---
### Parameters
|Name |Description|Datatype |Max length |Type |ReadOnly|
|-|-|-|-|-|-|
|@ErrorLogID|Output parameter for the stored procedure uspLogError. Contains the ErrorLogID value corresponding to the row inserted by uspLogError in the ErrorLog table.|int|4|Input/output or output|![](../../../../ImagesMetro/RED_CROSS.gif "")|

---
### Recordsets returned
 No recordsets returned

---
### Objects that depend on \[dbo\].\[uspLogError\]
|Object name|Object type|Dep level|
|-|-|-|
|[\[dbo\].\[uspAddOrderTrackingEvent\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Procedures/2029250284.md)|Procedure|1|
|[\[HumanResources\].\[uspUpdateEmployeeHireInfo\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Procedures/1565248631.md)|Procedure|1|
|[\[HumanResources\].\[uspUpdateEmployeeLogin\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Procedures/1581248688.md)|Procedure|1|
|[\[HumanResources\].\[uspUpdateEmployeePersonalInfo\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Procedures/1597248745.md)|Procedure|1|
|[\[Purchasing\].\[dVendor\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Triggers/973246522.md)|Trigger|1|
|[\[Sales\].\[iduSalesOrderDetail\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Triggers/941246408.md)|Trigger|1|
|[\[Purchasing\].\[iPurchaseOrderDetail\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Triggers/893246237.md)|Trigger|1|
|[\[Production\].\[iWorkOrder\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Triggers/989246579.md)|Trigger|1|
|[\[Purchasing\].\[uPurchaseOrderDetail\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Triggers/909246294.md)|Trigger|1|
|[\[Purchasing\].\[uPurchaseOrderHeader\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Triggers/925246351.md)|Trigger|1|
|[\[Sales\].\[uSalesOrderHeader\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Triggers/957246465.md)|Trigger|1|
|[\[Production\].\[uWorkOrder\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Triggers/1005246636.md)|Trigger|1|

 Total 12 object(s)

---
### Objects that \[dbo\].\[uspLogError\] depends on
|Object name|Object type|Dep level|
|-|-|-|
|[\[dbo\].\[uspPrintError\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Procedures/645577338.md)|Procedure|1|
|[\[dbo\].\[ErrorLog\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/597577167.md)|Table|1|

 Total 2 object(s)

---
### Column level dependencies
|Object name|Column|Object type|
|-|-|-|
|[\[dbo\].\[ErrorLog\]](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Tables/597577167.md)|*|Table|

 Total 1 column(s)

---
### Graphical dependencies
Click [here](../../../../DbEngine/(local)/AdventureWorks2016CTP3/Procedures/661577395_gr.md) to view dependencies graphically

---
###  Permissions
No permissions defined

---
###  Extended properties  
|Name |Value |
|-|-|
|MS_Description|Logs error information in the ErrorLog table about the error that caused execution to jump to the CATCH block of a TRY...CATCH construct. Should be executed from within the scope of a CATCH block otherwise it will return without inserting error information.|

---
### SQL
~~~SQL
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
GO

-- uspLogError logs error information in the ErrorLog table about the 
-- error that caused execution to jump to the CATCH block of a 
-- TRY...CATCH construct. This should be executed from within the scope 
-- of a CATCH block otherwise it will return without inserting error 
-- information. 
CREATE PROCEDURE [dbo].[uspLogError] 
    @ErrorLogID [int] = 0 OUTPUT -- contains the ErrorLogID of the row inserted
AS                               -- by uspLogError in the ErrorLog table
BEGIN
    SET NOCOUNT ON;

    -- Output parameter value of 0 indicates that error 
    -- information was not logged
    SET @ErrorLogID = 0;

    BEGIN TRY
        -- Return if there is no error information to log
        IF ERROR_NUMBER() IS NULL
            RETURN;

        -- Return if inside an uncommittable transaction.
        -- Data insertion/modification is not allowed when 
        -- a transaction is in an uncommittable state.
        IF XACT_STATE() = -1
        BEGIN
            PRINT 'Cannot log error since the current transaction is in an uncommittable state. ' 
                + 'Rollback the transaction before executing uspLogError in order to successfully log error information.';
            RETURN;
        END

        INSERT [dbo].[ErrorLog] 
            (
            [UserName], 
            [ErrorNumber], 
            [ErrorSeverity], 
            [ErrorState], 
            [ErrorProcedure], 
            [ErrorLine], 
            [ErrorMessage]
            ) 
        VALUES 
            (
            CONVERT(sysname, CURRENT_USER), 
            ERROR_NUMBER(),
            ERROR_SEVERITY(),
            ERROR_STATE(),
            ERROR_PROCEDURE(),
            ERROR_LINE(),
            ERROR_MESSAGE()
            );

        -- Pass back the ErrorLogID of the row inserted
        SET @ErrorLogID = @@IDENTITY;
    END TRY
    BEGIN CATCH
        PRINT 'An error occurred in stored procedure uspLogError: ';
        EXECUTE [dbo].[uspPrintError];
        RETURN -1;
    END CATCH
END;
GO
EXEC sp_addextendedproperty N'MS_Description', N'Logs error information in the ErrorLog table about the error that caused execution to jump to the CATCH block of a TRY...CATCH construct. Should be executed from within the scope of a CATCH block otherwise it will return without inserting error information.', 'SCHEMA', N'dbo', 'PROCEDURE', N'uspLogError', NULL, NULL
GO
EXEC sp_addextendedproperty N'MS_Description', N'Output parameter for the stored procedure uspLogError. Contains the ErrorLogID value corresponding to the row inserted by uspLogError in the ErrorLog table.', 'SCHEMA', N'dbo', 'PROCEDURE', N'uspLogError', 'PARAMETER', N'@ErrorLogID'
GO
  
~~~

---
### See also
[List of procedures](../procedures.md)

